/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DExtras.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 44 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 97 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 302 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 100 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 726 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 103 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 106 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 109 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 112 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 115 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 118 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 121 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 412 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 124 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 425 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 127 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 795 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 130 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 133 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurface.sip"
#include <qsurface.h>
#line 136 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 139 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 148 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 159 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 172 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 187 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 204 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 223 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 244 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 267 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 292 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 319 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 348 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 379 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 412 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 447 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 484 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 523 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 566 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 607 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 652 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 699 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 748 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 799 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 852 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 907 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 964 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 1023 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 1084 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 1147 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 1212 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 1279 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 1348 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 1419 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 1492 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 36 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 1567 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturematerial.sip"
#include <qtexturematerial.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturematerial.sip"
#include <qtexturematerial.h>
#line 1644 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturematerial.sip"
#include <qtexturematerial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusgeometry.sip"
#include <qtorusgeometry.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusgeometry.sip"
#include <qtorusgeometry.h>
#line 1723 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractcameracontroller.sip"
#include <qabstractcameracontroller.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qabstractspritesheet.sip"
#include <qabstractspritesheet.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconegeometry.sip"
#include <qconegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qconemesh.sip"
#include <qconemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidgeometry.sip"
#include <qcuboidgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcuboidmesh.sip"
#include <qcuboidmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindergeometry.sip"
#include <qcylindergeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qcylindermesh.sip"
#include <qcylindermesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusemapmaterial.sip"
#include <qdiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmapmaterial.sip"
#include <qdiffusespecularmapmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qdiffusespecularmaterial.sip"
#include <qdiffusespecularmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextgeometry.sip"
#include <qextrudedtextgeometry.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qextrudedtextmesh.sip"
#include <qextrudedtextmesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qfirstpersoncameracontroller.sip"
#include <qfirstpersoncameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qforwardrenderer.sip"
#include <qforwardrenderer.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qgoochmaterial.sip"
#include <qgoochmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmetalroughmaterial.sip"
#include <qmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qmorphphongmaterial.sip"
#include <qmorphphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapalphamaterial.sip"
#include <qnormaldiffusemapalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusemapmaterial.sip"
#include <qnormaldiffusemapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qnormaldiffusespecularmapmaterial.sip"
#include <qnormaldiffusespecularmapmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qorbitcameracontroller.sip"
#include <qorbitcameracontroller.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qpervertexcolormaterial.sip"
#include <qpervertexcolormaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongalphamaterial.sip"
#include <qphongalphamaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qphongmaterial.sip"
#include <qphongmaterial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanegeometry.sip"
#include <qplanegeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qplanemesh.sip"
#include <qplanemesh.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qskyboxentity.sip"
#include <qskyboxentity.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheregeometry.sip"
#include <qspheregeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspheremesh.sip"
#include <qspheremesh.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritegrid.sip"
#include <qspritegrid.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheet.sip"
#include <qspritesheet.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qspritesheetitem.sip"
#include <qspritesheetitem.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
#include <qt3dwindow.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtext2dentity.sip"
#include <qtext2dentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturedmetalroughmaterial.sip"
#include <qtexturedmetalroughmaterial.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtexturematerial.sip"
#include <qtexturematerial.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusgeometry.sip"
#include <qtorusgeometry.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusmesh.sip"
#include <qtorusmesh.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qtorusmesh.sip"
#include <qtorusmesh.h>
#line 1804 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_Qt3DExtras[] = {
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'N', 'o', 'r', 'm', 'a', 'l', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'S', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 'M', 'a', 'p', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'N', 'o', 'r', 'm', 'a', 'l', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'M', 'a', 'p', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'F', 'i', 'r', 's', 't', 'P', 'e', 'r', 's', 'o', 'n', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'S', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 'M', 'a', 'p', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'd', 'M', 'e', 't', 'a', 'l', 'R', 'o', 'u', 'g', 'h', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'r', 'i', 't', 'e', 'S', 'h', 'e', 'e', 't', 'I', 't', 'e', 'm', '*', '>', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'N', 'o', 'r', 'm', 'a', 'l', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'M', 'a', 'p', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'S', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'P', 'e', 'r', 'V', 'e', 'r', 't', 'e', 'x', 'C', 'o', 'l', 'o', 'r', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'O', 'r', 'b', 'i', 't', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'E', 'x', 't', 'r', 'u', 'd', 'e', 'd', 'T', 'e', 'x', 't', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'p', 'r', 'i', 't', 'e', 'S', 'h', 'e', 'e', 't', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'D', 'i', 'f', 'f', 'u', 's', 'e', 'M', 'a', 'p', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'M', 'e', 't', 'a', 'l', 'R', 'o', 'u', 'g', 'h', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'M', 'o', 'r', 'p', 'h', 'P', 'h', 'o', 'n', 'g', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'P', 'h', 'o', 'n', 'g', 'A', 'l', 'p', 'h', 'a', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'y', 'l', 'i', 'n', 'd', 'e', 'r', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'E', 'x', 't', 'r', 'u', 'd', 'e', 'd', 'T', 'e', 'x', 't', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'F', 'o', 'r', 'w', 'a', 'r', 'd', 'R', 'e', 'n', 'd', 'e', 'r', 'e', 'r', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'r', 'i', 't', 'e', 'S', 'h', 'e', 'e', 't', 'I', 't', 'e', 'm', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'f', 'r', 'u', 's', 't', 'u', 'm', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'u', 'b', 'o', 'i', 'd', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'h', 'e', 'r', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'a', 'l', 'p', 'h', 'a', 'B', 'l', 'e', 'n', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'G', 'o', 'o', 'c', 'h', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'P', 'h', 'o', 'n', 'g', 'M', 'a', 't', 'e', 'r', 'i', 'a', 'l', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'P', 'l', 'a', 'n', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'T', 'o', 'r', 'u', 's', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'a', 'm', 'm', 'a', 'C', 'o', 'r', 'r', 'e', 'c', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'o', 'n', 'e', 'G', 'e', 'o', 'm', 'e', 't', 'r', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'y', 'l', 'i', 'n', 'd', 'e', 'r', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'k', 'y', 'b', 'o', 'x', 'E', 'n', 't', 'i', 't', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'T', 'e', 'x', 't', '2', 'D', 'E', 'n', 't', 'i', 't', 'y', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'r', 'i', 't', 'e', 'S', 'h', 'e', 'e', 't', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'A', 'r', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'R', 'e', 'n', 'd', 'e', 'r', 'T', 'a', 'r', 'g', 'e', 't', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'F', 'r', 'u', 's', 't', 'u', 'm', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'u', 'b', 'o', 'i', 'd', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'h', 'e', 'r', 'e', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'S', 'p', 'r', 'i', 't', 'e', 'G', 'r', 'i', 'd', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 'O', 'c', 'c', 'l', 'u', 's', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'A', 'r', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'T', 'a', 'n', 'g', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'F', 'r', 'u', 's', 't', 'u', 'm', 'C', 'u', 'l', 'l', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'B', 'l', 'e', 'n', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'D', 'e', 'b', 'u', 'g', 'O', 'v', 'e', 'r', 'l', 'a', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'y', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'P', 'l', 'a', 'n', 'e', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'T', 'o', 'r', 'u', 's', 'M', 'e', 's', 'h', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 't', '3', 'D', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'h', 'a', 's', 'B', 'o', 't', 't', 'o', 'm', 'E', 'n', 'd', 'c', 'a', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'A', 'l', 'p', 'h', 'a', 'B', 'l', 'e', 'n', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 0,
    's', 'e', 't', 'G', 'a', 'm', 'm', 'a', 'C', 'o', 'r', 'r', 'e', 'c', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', ':', ':', 'Q', 'C', 'o', 'n', 'e', 'M', 'e', 's', 'h', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 'T', 'o', 'C', 'l', 'e', 'a', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'G', 'a', 'm', 'm', 'a', 'C', 'o', 'r', 'r', 'e', 'c', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'm', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'D', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'A', 'r', 'g', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'o', 't', 't', 'o', 'm', 'R', 'a', 'd', 'i', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 0,
    'h', 'a', 's', 'T', 'o', 'p', 'E', 'n', 'd', 'c', 'a', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    's', 'e', 't', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'O', 'c', 'c', 'l', 'u', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'A', 'r', 'g', 0,
    's', 'e', 't', 'G', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'T', 'a', 'n', 'g', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'S', 'h', 'o', 'w', 'D', 'e', 'b', 'u', 'g', 'O', 'v', 'e', 'r', 'l', 'a', 'y', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'X', 'Y', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'X', 'Z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'Y', 'Z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'A', 'r', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'R', 'e', 'c', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'n', 'e', 'a', 'r', 'S', 'p', 'e', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'R', 'a', 'd', 'i', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'H', 'a', 's', 'B', 'o', 't', 't', 'o', 'm', 'E', 'n', 'd', 'c', 'a', 'p', 0,
    'z', 'o', 'o', 'm', 'I', 'n', 'L', 'i', 'm', 'i', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'R', 'g', 'b', 'A', 'r', 'g', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'u', 'f', 'f', 'e', 'r', 's', 'T', 'o', 'C', 'l', 'e', 'a', 'r', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 0,
    't', 'e', 'x', 'C', 'o', 'o', 'r', 'd', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', '3', 'D', 'E', 'x', 't', 'r', 'a', 's', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'r', 'a', 'p', 'h', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 'O', 'c', 'c', 'l', 'u', 's', 'i', 'o', 'n', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'l', 'e', 'n', 'd', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'A', 'r', 'g', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'T', 'a', 'n', 'g', 'e', 'n', 't', 's', 0,
    'l', 'o', 'o', 'k', 'S', 'p', 'e', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 't', 'a', 'l', 'n', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'h', 'i', 'n', 'i', 'n', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'D', 'e', 'b', 'u', 'g', 'O', 'v', 'e', 'r', 'l', 'a', 'y', 0,
    't', 'a', 'n', 'g', 'e', 'n', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    't', 'o', 'p', 'R', 'a', 'd', 'i', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'y', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'x', 'z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'y', 'z', 'M', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'b', 'a', 's', 'e', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 't', 'r', 'u', 's', 'i', 'o', 'n', 'L', 'e', 'n', 'g', 't', 'h', 0,
    'h', 'a', 's', 'B', 'o', 't', 't', 'o', 'm', 'E', 'n', 'd', 'c', 'a', 'p', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'o', 't', 't', 'o', 'm', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'D', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'H', 'a', 's', 'T', 'o', 'p', 'E', 'n', 'd', 'c', 'a', 'p', 0,
    's', 'e', 't', 'I', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'o', 'r', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'A', 'r', 'g', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'R', 'e', 'c', 't', 0,
    's', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'u', 'f', 'f', 'e', 'r', 's', 'T', 'o', 'C', 'l', 'e', 'a', 'r', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'i', 'f', 'f', 'u', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'd', 'e', 'x', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'm', 'e', 's', 'h', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'A', 's', 'p', 'e', 'c', 't', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'L', 'i', 'n', 'e', 'a', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'e', 't', 'M', 'i', 'n', 'o', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'I', 'n', 'L', 'i', 'm', 'i', 't', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'A', 'l', 'p', 'h', 'a', 'A', 'r', 'g', 0,
    's', 'p', 'r', 'i', 't', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'V', 'e', 'r', 't', 'i', 'c', 'e', 's', 0,
    'x', 'E', 'x', 't', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'E', 'x', 't', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'E', 'x', 't', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'a', 'd', 'i', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'R', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'o', 'o', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'l', 'i', 'c', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'O', 'f', 'f', 's', 'e', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 'I', 'n', 'd', 'i', 'c', 'e', 's', 0,
    'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'l', 'p', 'h', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'o', 't', 't', 'o', 'm', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'c', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'd', 'e', 'p', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'a', 'm', 'm', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'a', 's', 'T', 'o', 'p', 'E', 'n', 'd', 'c', 'a', 'p', 0,
    'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'o', 'r', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'p', 'r', 'i', 't', 'e', 0,
    'r', 'i', 'n', 'g', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'o', 'o', 'k', 'S', 'p', 'e', 'e', 'd', 0,
    's', 'e', 't', 'M', 'e', 't', 'a', 'l', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'R', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'S', 'h', 'i', 'n', 'i', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'T', 'o', 'p', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'R', 'g', 'b', 'A', 'r', 'g', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'S', 'c', 'a', 'l', 'e', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'R', 'e', 'c', 't', 0,
    'w', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'e', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'o', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'f', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'n', 'e', 'a', 'r', 'S', 'p', 'e', 'e', 'd', 0,
    'm', 'i', 'n', 'o', 'r', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'e', 'v', 'i', 'c', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'o', 'w', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'M', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    's', 'e', 't', 'S', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'a', 'r', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'o', 'o', 'm', 'I', 'n', 'L', 'i', 'm', 'i', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'e', 'a', 'r', 'C', 'o', 'l', 'o', 'r', 0,
    'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'A', 'm', 'b', 'i', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 's', 0,
    's', 'e', 't', 'D', 'i', 'f', 'f', 'u', 's', 'e', 0,
    's', 'e', 't', 'S', 'p', 'r', 'i', 't', 'e', 's', 0,
    's', 'e', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'X', 'E', 'x', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'Y', 'E', 'x', 't', 'e', 'n', 't', 0,
    's', 'e', 't', 'Z', 'E', 'x', 't', 'e', 'n', 't', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'a', 'd', 'd', 'S', 'p', 'r', 'i', 't', 'e', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'o', 'o', 'k', 'S', 'p', 'e', 'e', 'd', 0,
    'm', 'e', 't', 'a', 'l', 'n', 'e', 's', 's', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'L', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'N', 'o', 'r', 'm', 'a', 'l', 0,
    's', 'e', 't', 'R', 'a', 'd', 'i', 'u', 's', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 's', 0,
    's', 'h', 'i', 'n', 'i', 'n', 'e', 's', 's', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'p', 'R', 'a', 'd', 'i', 'u', 's', 0,
    'b', 'a', 's', 'e', 'N', 'a', 'm', 'e', 0,
    'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'D', 'e', 'p', 't', 'h', 0,
    's', 'e', 't', 'G', 'a', 'm', 'm', 'a', 0,
    's', 'e', 't', 'R', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'W', 'i', 'd', 't', 'h', 0,
    's', 'p', 'e', 'c', 'u', 'l', 'a', 'r', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 's', 0,
    'd', 'i', 'f', 'f', 'u', 's', 'e', 0,
    's', 'e', 't', 'B', 'e', 't', 'a', 0,
    's', 'e', 't', 'C', 'o', 'o', 'l', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'R', 'o', 'w', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'W', 'a', 'r', 'm', 0,
    's', 'p', 'r', 'i', 't', 'e', 's', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'x', 'E', 'x', 't', 'e', 'n', 't', 0,
    'y', 'E', 'x', 't', 'e', 'n', 't', 0,
    'z', 'E', 'x', 't', 'e', 'n', 't', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'h', 'e', 'i', 'g', 'h', 't', 0,
    'l', 'e', 'n', 'g', 't', 'h', 0,
    'n', 'o', 'r', 'm', 'a', 'l', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'a', 'd', 'i', 'u', 's', 0,
    's', 'c', 'r', 'e', 'e', 'n', 0,
    's', 'l', 'i', 'c', 'e', 's', 0,
    'a', 'l', 'p', 'h', 'a', 0,
    'c', 'o', 'l', 'o', 'r', 0,
    'd', 'e', 'p', 't', 'h', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'g', 'a', 'm', 'm', 'a', 0,
    'r', 'i', 'n', 'g', 's', 0,
    'w', 'i', 'd', 't', 'h', 0,
    'b', 'e', 't', 'a', 0,
    'c', 'o', 'o', 'l', 0,
    'f', 'o', 'n', 't', 0,
    'r', 'o', 'w', 's', 0,
    's', 'e', 't', 'X', 0,
    's', 'e', 't', 'Y', 0,
    's', 'i', 'z', 'e', 0,
    't', 'e', 'x', 't', 0,
    'w', 'a', 'r', 'm', 0,
};

::QSize sipVH_Qt3DExtras_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

::QSurface::SurfaceType sipVH_Qt3DExtras_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurface::SurfaceType sipRes = ::QSurface::RasterSurface;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSurface_SurfaceType, &sipRes);

    return sipRes;
}

::QSurfaceFormat sipVH_Qt3DExtras_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSurfaceFormat, &sipRes);

    return sipRes;
}

::QObject* sipVH_Qt3DExtras_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_Qt3DExtras_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QExposeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QExposeEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTouchEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTouchEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QSceneChangePtr& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QSceneChangePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, SIP_NULLPTR);
}

bool sipVH_Qt3DExtras_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_Qt3DExtras_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_Qt3DExtras_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_Qt3DExtras_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_Qt3DExtras_Qt3DWindow(void **);}
static const sipTypeDef *sipSubClass_Qt3DExtras_Qt3DWindow(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 40 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DExtras/qt3dwindow.sip"
static struct class_graph {
    const char *name;
    sipTypeDef **type;
    int yes, no;
} graph[] = {
    {sipName_Qt3DExtras__QAbstractCameraController, &sipType_Qt3DExtras_QAbstractCameraController, 33, 1},
    {sipName_Qt3DExtras__QAbstractSpriteSheet, &sipType_Qt3DExtras_QAbstractSpriteSheet, 35, 2},
    {sipName_Qt3DExtras__QConeGeometry, &sipType_Qt3DExtras_QConeGeometry, -1, 3},
    {sipName_Qt3DExtras__QConeMesh, &sipType_Qt3DExtras_QConeMesh, -1, 4},
    {sipName_Qt3DExtras__QCuboidGeometry, &sipType_Qt3DExtras_QCuboidGeometry, -1, 5},
    {sipName_Qt3DExtras__QCuboidMesh, &sipType_Qt3DExtras_QCuboidMesh, -1, 6},
    {sipName_Qt3DExtras__QCylinderGeometry, &sipType_Qt3DExtras_QCylinderGeometry, -1, 7},
    {sipName_Qt3DExtras__QCylinderMesh, &sipType_Qt3DExtras_QCylinderMesh, -1, 8},
    {sipName_Qt3DExtras__QDiffuseMapMaterial, &sipType_Qt3DExtras_QDiffuseMapMaterial, -1, 9},
    {sipName_Qt3DExtras__QDiffuseSpecularMapMaterial, &sipType_Qt3DExtras_QDiffuseSpecularMapMaterial, -1, 10},
    {sipName_Qt3DExtras__QDiffuseSpecularMaterial, &sipType_Qt3DExtras_QDiffuseSpecularMaterial, -1, 11},
    {sipName_Qt3DExtras__QExtrudedTextGeometry, &sipType_Qt3DExtras_QExtrudedTextGeometry, -1, 12},
    {sipName_Qt3DExtras__QExtrudedTextMesh, &sipType_Qt3DExtras_QExtrudedTextMesh, -1, 13},
    {sipName_Qt3DExtras__QForwardRenderer, &sipType_Qt3DExtras_QForwardRenderer, -1, 14},
    {sipName_Qt3DExtras__QGoochMaterial, &sipType_Qt3DExtras_QGoochMaterial, -1, 15},
    {sipName_Qt3DExtras__QMetalRoughMaterial, &sipType_Qt3DExtras_QMetalRoughMaterial, 37, 16},
    {sipName_Qt3DExtras__QMorphPhongMaterial, &sipType_Qt3DExtras_QMorphPhongMaterial, -1, 17},
    {sipName_Qt3DExtras__QNormalDiffuseMapMaterial, &sipType_Qt3DExtras_QNormalDiffuseMapMaterial, 38, 18},
    {sipName_Qt3DExtras__QNormalDiffuseSpecularMapMaterial, &sipType_Qt3DExtras_QNormalDiffuseSpecularMapMaterial, -1, 19},
    {sipName_Qt3DExtras__QPerVertexColorMaterial, &sipType_Qt3DExtras_QPerVertexColorMaterial, -1, 20},
    {sipName_Qt3DExtras__QPhongAlphaMaterial, &sipType_Qt3DExtras_QPhongAlphaMaterial, -1, 21},
    {sipName_Qt3DExtras__QPhongMaterial, &sipType_Qt3DExtras_QPhongMaterial, -1, 22},
    {sipName_Qt3DExtras__QPlaneGeometry, &sipType_Qt3DExtras_QPlaneGeometry, -1, 23},
    {sipName_Qt3DExtras__QPlaneMesh, &sipType_Qt3DExtras_QPlaneMesh, -1, 24},
    {sipName_Qt3DExtras__QSkyboxEntity, &sipType_Qt3DExtras_QSkyboxEntity, -1, 25},
    {sipName_Qt3DExtras__QSphereGeometry, &sipType_Qt3DExtras_QSphereGeometry, -1, 26},
    {sipName_Qt3DExtras__QSphereMesh, &sipType_Qt3DExtras_QSphereMesh, -1, 27},
    {sipName_Qt3DExtras__QSpriteSheetItem, &sipType_Qt3DExtras_QSpriteSheetItem, -1, 28},
    {sipName_Qt3DExtras__QText2DEntity, &sipType_Qt3DExtras_QText2DEntity, -1, 29},
    {sipName_Qt3DExtras__QTextureMaterial, &sipType_Qt3DExtras_QTextureMaterial, -1, 30},
    {sipName_Qt3DExtras__QTorusGeometry, &sipType_Qt3DExtras_QTorusGeometry, -1, 31},
    {sipName_Qt3DExtras__QTorusMesh, &sipType_Qt3DExtras_QTorusMesh, -1, 32},
    {sipName_Qt3DExtras__Qt3DWindow, &sipType_Qt3DExtras_Qt3DWindow, -1, -1},
    {sipName_Qt3DExtras__QFirstPersonCameraController, &sipType_Qt3DExtras_QFirstPersonCameraController, -1, 34},
    {sipName_Qt3DExtras__QOrbitCameraController, &sipType_Qt3DExtras_QOrbitCameraController, -1, -1},
    {sipName_Qt3DExtras__QSpriteGrid, &sipType_Qt3DExtras_QSpriteGrid, -1, 36},
    {sipName_Qt3DExtras__QSpriteSheet, &sipType_Qt3DExtras_QSpriteSheet, -1, -1},
    {sipName_Qt3DExtras__QTexturedMetalRoughMaterial, &sipType_Qt3DExtras_QTexturedMetalRoughMaterial, -1, -1},
    {sipName_Qt3DExtras__QNormalDiffuseMapAlphaMaterial, &sipType_Qt3DExtras_QNormalDiffuseMapAlphaMaterial, -1, -1},
};

int i = 0;

sipType = NULL;

do
{
    struct class_graph *cg = &graph[i];

    if (cg->name != NULL && sipCpp->inherits(cg->name))
    {
        sipType = *cg->type;
        i = cg->yes;
    }
    else
        i = cg->no;
}
while (i >= 0);
#line 2322 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DExtras/sipQt3DExtrascmodule.cpp"

    return sipType;
}


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_Qt3DExtras[] = {
    &sipTypeDef_Qt3DExtras_QVector_0101Qt3DExtras_QSpriteSheetItem.mtd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QAbstractCameraController.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QAbstractSpriteSheet.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QConeGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QConeMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QCuboidGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QCuboidMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QCylinderGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QCylinderMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseMapMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseSpecularMapMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QDiffuseSpecularMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QExtrudedTextGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QExtrudedTextMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QFirstPersonCameraController.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QForwardRenderer.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QGoochMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QMetalRoughMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QMorphPhongMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseMapAlphaMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseMapMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QNormalDiffuseSpecularMapMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QOrbitCameraController.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QPerVertexColorMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QPhongAlphaMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QPhongMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QPlaneGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QPlaneMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSkyboxEntity.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSphereGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSphereMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteGrid.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteSheet.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QSpriteSheetItem.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QText2DEntity.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QTextureMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QTexturedMetalRoughMaterial.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QTorusGeometry.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_QTorusMesh.ctd_base,
    &sipTypeDef_Qt3DExtras_Qt3DExtras_Qt3DWindow.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_Qt3DExtras_QtCore[] = {
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QRectF"},
    {"QSize"},
    {"QString"},
    {"QTimerEvent"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DExtras_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_Qt3DExtras_QtGui[] = {
    {"QColor"},
    {"QExposeEvent"},
    {"QFocusEvent"},
    {"QFont"},
    {"QHideEvent"},
    {"QKeyEvent"},
    {"QMatrix3x3"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QResizeEvent"},
    {"QScreen"},
    {"QShowEvent"},
    {"QSurface"},
    {"QSurface::SurfaceType"},
    {"QSurfaceFormat"},
    {"QTabletEvent"},
    {"QTouchEvent"},
    {"QVector2D"},
    {"QWheelEvent"},
    {"QWindow"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DCore. */
sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DCore[] = {
    {"QSharedPointer<Qt3DCore::QSceneChange>"},
    {"Qt3DCore::QAbstractAspect"},
    {"Qt3DCore::QComponent"},
    {"Qt3DCore::QEntity"},
    {"Qt3DCore::QNode"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DInput. */
sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DInput[] = {
    {"Qt3DInput::QKeyboardDevice"},
    {"Qt3DInput::QMouseDevice"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from Qt3DRender. */
sipImportedTypeDef sipImportedTypes_Qt3DExtras_Qt3DRender[] = {
    {"Qt3DRender::QAbstractTexture"},
    {"Qt3DRender::QAttribute"},
    {"Qt3DRender::QBlendEquation::BlendFunction"},
    {"Qt3DRender::QBlendEquationArguments::Blending"},
    {"Qt3DRender::QCamera"},
    {"Qt3DRender::QClearBuffers::BufferType"},
    {"Qt3DRender::QFrameGraphNode"},
    {"Qt3DRender::QGeometry"},
    {"Qt3DRender::QGeometryRenderer"},
    {"Qt3DRender::QMaterial"},
    {"Qt3DRender::QRenderSettings"},
    {"Qt3DRender::QTechniqueFilter"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_Qt3DExtras_QtCore, sipImportedVirtErrorHandlers_Qt3DExtras_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_Qt3DExtras_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DCore", sipImportedTypes_Qt3DExtras_Qt3DCore, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DInput", sipImportedTypes_Qt3DExtras_Qt3DInput, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.Qt3DRender", sipImportedTypes_Qt3DExtras_Qt3DRender, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_Qt3DExtras_Qt3DWindow, {3, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_Qt3DExtras = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_Qt3DExtras,
    0,
    sipStrings_Qt3DExtras,
    importsTable,
    SIP_NULLPTR,
    40,
    sipExportedTypes_Qt3DExtras,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_Qt3DExtras;

sip_qt_metaobject_func sip_Qt3DExtras_qt_metaobject;
sip_qt_metacall_func sip_Qt3DExtras_qt_metacall;
sip_qt_metacast_func sip_Qt3DExtras_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_Qt3DExtras()
#else
PyMODINIT_FUNC PyInit_Qt3DExtras()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.Qt3DExtras",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_Qt3DExtras = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_Qt3DExtras == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_Qt3DExtras, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_Qt3DExtras_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_Qt3DExtras_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_Qt3DExtras_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_Qt3DExtras_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_Qt3DExtras, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
